==> jc-1.4.0.tar.gz: gnu/java/awt/peer/gtk/GtkGenericPeer.h <==
// public class gnu.java.awt.peer.gtk.GtkGenericPeer

// class file dependencies
// @dep_class d6f9e33c09f7be67 gnu_java_awt_peer_gtk_GtkGenericPeer
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_awt_peer_gtk_GtkGenericPeer_H_
#define _JC_gnu_java_awt_peer_gtk_GtkGenericPeer_H_

// Forward structure declarations
struct _jc_java_awt_EventQueue$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$sub_refs	_jc_gnu_java_awt_peer_gtk_GtkGenericPeer$sub_refs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$sub_nonrefs	_jc_gnu_java_awt_peer_gtk_GtkGenericPeer$sub_nonrefs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$refs	_jc_gnu_java_awt_peer_gtk_GtkGenericPeer$refs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$nonrefs	_jc_gnu_java_awt_peer_gtk_GtkGenericPeer$nonrefs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$object	_jc_gnu_java_awt_peer_gtk_GtkGenericPeer$object;

typedef struct _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$fields_struct	_jc_gnu_java_awt_peer_gtk_GtkGenericPeer$fields_struct;
typedef const struct _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$vmethods	_jc_gnu_java_awt_peer_gtk_GtkGenericPeer$vmethods;
typedef const struct _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$vtable	_jc_gnu_java_awt_peer_gtk_GtkGenericPeer$vtable;
typedef const struct _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$vtype	_jc_gnu_java_awt_peer_gtk_GtkGenericPeer$vtype;

// Class fields structure
struct _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$fields_struct {
	struct _jc_java_awt_EventQueue$object	*q;
	jint	next__5fnative__5fstate;
};
extern _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$fields_struct _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$class_fields;

// Constructors
extern void _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$method$_init$3fddd28dadb712ab(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$object *, struct _jc_java_lang_Object$object *);

// Virtual methods
extern void _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$method$dispose$9d5b5b52b7878138(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$object *);
extern void _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$method$gtkWidgetModifyFont$cbd31df1d0d5c3cd(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$object *, struct _jc_java_lang_String$object *, jint, jint);
extern void _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$method$postActionEvent$2b0876ab9ab28f8e(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$object *, struct _jc_java_lang_String$object *, jint);
extern void _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$method_info$dispose$9d5b5b52b7878138;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$method_info$gtkWidgetModifyFont$cbd31df1d0d5c3cd;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$method_info$postActionEvent$2b0876ab9ab28f8e;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$method_info$this$adc93fb6bf4cbffa;

// Static methods
extern void _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$method$_clinit$a816641e0ba8bfef(_jc_env *);
extern void _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$method$enableQueue$f6b770617ed08814(_jc_env *, struct _jc_java_awt_EventQueue$object *);
extern jint _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$method$getUniqueInteger$ce7784deebf335b6(_jc_env *);
extern struct _jc_java_awt_EventQueue$object *_jc_gnu_java_awt_peer_gtk_GtkGenericPeer$method$q$ae77ba1fe28b574f(_jc_env *);

// Virtual methods structure
struct _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$vmethods {
	void	(*dispose$9d5b5b52b7878138)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$object *);
	void	(*gtkWidgetModifyFont$cbd31df1d0d5c3cd)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$object *, struct _jc_java_lang_String$object *, jint, jint);
	void	(*postActionEvent$2b0876ab9ab28f8e)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$object *, struct _jc_java_lang_String$object *, jint);
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$object *);
};

// Vtable
struct _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_awt_peer_gtk_GtkGenericPeer$vmethods	gnu_java_awt_peer_gtk_GtkGenericPeer;
};

// Vtype
struct _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$vtype {
	_jc_type			type;
	_jc_gnu_java_awt_peer_gtk_GtkGenericPeer$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$sub_refs {
	struct _jc_java_lang_Object$object	*awtWidget;
};

// Reference instance fields (object)
struct _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$refs {
    _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$sub_refs	gnu_java_awt_peer_gtk_GtkGenericPeer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$sub_nonrefs {
	jint	native__5fstate;
};

// Non-reference instance fields (object)
struct _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$sub_nonrefs	gnu_java_awt_peer_gtk_GtkGenericPeer;
};

// Object instance structure
struct _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$object {
	_jc_gnu_java_awt_peer_gtk_GtkGenericPeer$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_awt_peer_gtk_GtkGenericPeer$vtype	*vtype;
	_jc_gnu_java_awt_peer_gtk_GtkGenericPeer$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$vtype _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_awt_peer_gtk_GtkGenericPeer, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$class_object;

#endif	/* _JC_gnu_java_awt_peer_gtk_GtkGenericPeer_H_ */

==> jc-1.4.5.tar.gz: gnu/java/awt/peer/gtk/GtkGenericPeer.h <==
// public class gnu.java.awt.peer.gtk.GtkGenericPeer

// class file dependencies
// @dep_class d6f9e33c09f7be67 gnu_java_awt_peer_gtk_GtkGenericPeer
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_awt_peer_gtk_GtkGenericPeer_H_
#define _JC_gnu_java_awt_peer_gtk_GtkGenericPeer_H_

// Forward structure declarations
struct _jc_java_awt_EventQueue$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$sub_refs	_jc_gnu_java_awt_peer_gtk_GtkGenericPeer$sub_refs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$sub_nonrefs	_jc_gnu_java_awt_peer_gtk_GtkGenericPeer$sub_nonrefs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$refs	_jc_gnu_java_awt_peer_gtk_GtkGenericPeer$refs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$nonrefs	_jc_gnu_java_awt_peer_gtk_GtkGenericPeer$nonrefs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$object	_jc_gnu_java_awt_peer_gtk_GtkGenericPeer$object;

typedef struct _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$fields_struct	_jc_gnu_java_awt_peer_gtk_GtkGenericPeer$fields_struct;
typedef const struct _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$vmethods	_jc_gnu_java_awt_peer_gtk_GtkGenericPeer$vmethods;
typedef const struct _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$vtable	_jc_gnu_java_awt_peer_gtk_GtkGenericPeer$vtable;
typedef const struct _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$vtype	_jc_gnu_java_awt_peer_gtk_GtkGenericPeer$vtype;

// Class fields structure
struct _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$fields_struct {
	struct _jc_java_awt_EventQueue$object	*q;
	jint	next__5fnative__5fstate;
};
extern _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$fields_struct _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$class_fields;

// Constructors
extern void _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$method$_init$3fddd28dadb712ab(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$method$dispose$9d5b5b52b7878138(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$method$gtkWidgetModifyFont$cbd31df1d0d5c3cd(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$object *, struct _jc_java_lang_String$object *, jint, jint) _JC_JCNI_ATTR;
extern void _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$method$postActionEvent$2b0876ab9ab28f8e(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$object *, struct _jc_java_lang_String$object *, jint) _JC_JCNI_ATTR;
extern void _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$method_info$dispose$9d5b5b52b7878138;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$method_info$gtkWidgetModifyFont$cbd31df1d0d5c3cd;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$method_info$postActionEvent$2b0876ab9ab28f8e;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$method_info$this$adc93fb6bf4cbffa;

// Static methods
extern void _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$method$enableQueue$f6b770617ed08814(_jc_env *, struct _jc_java_awt_EventQueue$object *) _JC_JCNI_ATTR;
extern jint _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$method$getUniqueInteger$ce7784deebf335b6(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_java_awt_EventQueue$object *_jc_gnu_java_awt_peer_gtk_GtkGenericPeer$method$q$ae77ba1fe28b574f(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$vmethods {
	void	(*dispose$9d5b5b52b7878138)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$object *) _JC_JCNI_ATTR;
	void	(*gtkWidgetModifyFont$cbd31df1d0d5c3cd)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$object *, struct _jc_java_lang_String$object *, jint, jint) _JC_JCNI_ATTR;
	void	(*postActionEvent$2b0876ab9ab28f8e)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$object *, struct _jc_java_lang_String$object *, jint) _JC_JCNI_ATTR;
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_awt_peer_gtk_GtkGenericPeer$vmethods	gnu_java_awt_peer_gtk_GtkGenericPeer;
};

// Vtype
struct _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$vtype {
	_jc_type			type;
	_jc_gnu_java_awt_peer_gtk_GtkGenericPeer$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$sub_refs {
	struct _jc_java_lang_Object$object	*awtWidget;
};

// Reference instance fields (object)
struct _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$refs {
    _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$sub_refs	gnu_java_awt_peer_gtk_GtkGenericPeer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$sub_nonrefs {
	jint	native__5fstate;
};

// Non-reference instance fields (object)
struct _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$sub_nonrefs	gnu_java_awt_peer_gtk_GtkGenericPeer;
};

// Object instance structure
struct _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$object {
	_jc_gnu_java_awt_peer_gtk_GtkGenericPeer$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_awt_peer_gtk_GtkGenericPeer$vtype	*vtype;
	_jc_gnu_java_awt_peer_gtk_GtkGenericPeer$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$vtype _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_awt_peer_gtk_GtkGenericPeer, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$class_object;

#endif	/* _JC_gnu_java_awt_peer_gtk_GtkGenericPeer_H_ */
